@@ -32,7 +32,7 @@
 #' @param silent (logical) suppress messages
 #' @param callFrom (character) allow easier tracking of messages produced
 #' @param debug (logical) display additional messages for debugging
-#' @return plot, optional return of matrix with outlyers
+#' @return This function returns primarily a plot, optionally it may return of matrix with outlyers (if argument \code{returnOutL=TRUE})
 #' @seealso \code{\link{plotPCAw}}, \code{\link[stats]{princomp}}
 #' @examples
 #' set.seed(2020); dat1 <- matrix(round(rnorm(2000),3),ncol=2); rownames(dat1) <- 1:nrow(dat1)
@@ -56,7 +56,7 @@ addBagPlot <- function(x, lev1=0.5, outCoef=2, bagCol=NULL, bagCont=bagCol, bagL
   ## 'lev1' gives the min % of points to be included to core (shaded using 'bagCol'), as long as >nCore data-points available
   ## "outliers" are determined similar to boxplots using the 'outCoef'-parameter and then shown in color 'colOutL' and their names may be exported
   ## optional: overall contour (wo outliers) if 'colCont' (=color for contour) given, show center (median) if 'ctrPch' given
-  fxNa <- wrMisc::.composeCallName(callFrom, newNa=".addBagPlot")
+  fxNa <- wrMisc::.composeCallName(callFrom, newNa="addBagPlot")
   msg <- " 'x' must be numeric matrix or data.frame (with at least 1 row and 2 columns)"
   if(!isTRUE(silent)) silent <- FALSE
   if(isTRUE(debug)) silent <- FALSE else debug <- FALSE
@@ -71,7 +71,7 @@ addBagPlot <- function(x, lev1=0.5, outCoef=2, bagCol=NULL, bagCont=bagCol, bagL
   if(any(chNA)) {
     rmLi <- which(rowSums(chNA) >0)
     if(length(rmLi)==nrow(x)) { x <- NULL
-      message(fxNa,"Data contain too many NAs, no complete lines left")
+      if(!silent) message(fxNa,"Data contain too many NAs, no complete lines left")
     } else if(!silent) message(fxNa," ",length(rmLi)," lines contain NAs, can't consider/use them as points") }
   if(length(bagCol) <1) bagCol <- grDevices::rgb(0.1,0.1,0.1,0.1)
   ## main
@@ -97,19 +97,19 @@ addBagPlot <- function(x, lev1=0.5, outCoef=2, bagCol=NULL, bagCont=bagCol, bagL
     ## chull around core data
     xCore <- x
     liBag <- if(length(di) <4) rep(TRUE, length(di)) else di <= stats::quantile(di, lev1, na.rm=TRUE) +min(di,na.rm=TRUE)/100
-    if(sum(liBag) <4 & length(di) >2) liBag[order(di, decreasing=FALSE)[1:3]] <- TRUE   # have at least 3 points for bag
+    if(sum(liBag) <4 && length(di) >2) liBag[order(di, decreasing=FALSE)[1:3]] <- TRUE   # have at least 3 points for bag
     if(sum(liBag) < length(liBag)/2.7) liBag <- di <= stats::quantile(di, lev1, na.rm=TRUE) + mean(di,na.rm=TRUE)/10
-    if(sum(liBag) >1 & sum(liBag) < nrow(x)) xCore <- x[which(liBag),]
+    if(sum(liBag) >1 && sum(liBag) < nrow(x)) xCore <- x[which(liBag),]
     htps <- grDevices::chull(xCore)
     if(nrow(x) > 2) {
       ## shade core ...
       graphics::polygon(xCore[c(htps,htps[1]),], col=bagCol, border=bagCont)
       ## draw outer contour :
       htps2 <- grDevices::chull(x)
-      if(length(bagLwd) >0 & !all(is.na(bagCont))) { y <- x[htps2,]; y <- cbind(y, y[c(2:nrow(y),1),])
+      if(length(bagLwd) >0 && !all(is.na(bagCont))) { y <- x[htps2,]; y <- cbind(y, y[c(2:nrow(y),1),])
         graphics::segments(y[,1], y[,2], y[,3], y[,4], col=bagCont, lwd=bagLwd) }
       ## optional replotting of non-outlyer-points
-      if(length(reCol) >0 & length(rePch) >0 & length(reCex) >0) graphics::points(x, pch=rePch, col=reCol, cex=reCex)
+      if(length(reCol) >0 && length(rePch) >0 && length(reCex) >0) graphics::points(x, pch=rePch, col=reCol, cex=reCex)
     } else if(nrow(x)==2) graphics::lines(x[,1], x[,2], lwd=5, col=bagCol)      # can only connect 2 remaining points by fat line
     if(debug) {message(fxNa,"aBP3") }
 
@@ -123,8 +123,8 @@ addBagPlot <- function(x, lev1=0.5, outCoef=2, bagCol=NULL, bagCont=bagCol, bagL
       if(debug) {message(fxNa,"aBP4"); aBP4 <- list(ctr=ctr,x=x,lev1=lev1,outCoef=outCoef,outL=outL,outlPch=outlPch,outlCol=outlCol,addSubTi=addSubTi,outlCex=outlCex,
         offS=offS,bagCol=bagCol,bagCont=bagCont,bagLwd=bagLwd,silent=silent,debug=debug ) }
       if(length(outlPch) >0) graphics::points(outL, pch=outlPch, col=outlCol)
-      if(length(addSubTi) <1 | !is.logical(addSubTi)) addSubTi <- FALSE else if(length(addSubTi) >1) addSubTi <- any(as.logical(addSubTi), na.rm=TRUE)
-      if(addSubTi & length(outlCex) <1) graphics::mtext(paste("names of ",sum(!sapply(outL,is.null),na.rm=TRUE),
+      if(length(addSubTi) <1 || !is.logical(addSubTi)) addSubTi <- FALSE else if(length(addSubTi) >1) addSubTi <- any(as.logical(addSubTi), na.rm=TRUE)
+      if(addSubTi && length(outlCex) <1) graphics::mtext(paste("names of ",sum(!sapply(outL, is.null),na.rm=TRUE),
         " elements looking like potential outlyers were displayed"), cex=0.55, line=-0.8, col=grDevices::grey(0.4))
       if(length(outlCex) >0) graphics::text(outL[,1] +offS[1], outL[,2] +offS[2], col=outlCol, adj=0,cex=outlCex, labels=substr(rownames(outL),1,21))
       }
