@@ -34,15 +34,15 @@
 #' @examples
 #' set.seed(2016); dat1 <- round(c(rnorm(200,6,0.5),rlnorm(300,2,0.5),rnorm(100,17)),2)
 #' dat1 <- dat1[which(dat1 <50 & dat1 > 0.2)]
-#' histW(dat1,br="FD",isLog=FALSE)
-#' histW(log2(dat1),br="FD",isLog=TRUE)
+#' histW(dat1, br="FD", isLog=FALSE)
+#' histW(log2(dat1), br="FD", isLog=TRUE)
 #' 
 #' ## quick overview of distributions  
 #' layout(partitionPlot(4))
-#' for(i in 1:4) histW(iris[,i],isLog=FALSE,tit=colnames(iris)[i])
+#' for(i in 1:4) histW(iris[,i], isLog=FALSE, tit=colnames(iris)[i])
 #' @export
 histW <- function(dat, fileName="histW", output="screen", nBars=8, breaks=NULL, tit=NULL, subTi=NULL,xLab=NULL,yLab=NULL,las=NULL,xcex=0.7,
-  imgxSize=900, useCol=NULL, useBord=NULL, isLog=TRUE,cexSubTi=NULL,cropHist=TRUE,parDefault=TRUE,silent=FALSE,debug=FALSE,callFrom=NULL) {
+  imgxSize=900, useCol=NULL, useBord=NULL, isLog=TRUE, cexSubTi=NULL, cropHist=TRUE, parDefault=TRUE, silent=FALSE, debug=FALSE, callFrom=NULL) {
   ## make (small) histogram, eg as overview of bandwidth of values in 'dat'
   ## 'isLog'  .. for lin scale SI values where repesentation needs log
   ## 'breaks' .. for (partial) compatibility with hist() : use only for number of breaks (or 'FD'), gets priority over 'nBars'
@@ -61,7 +61,7 @@ histW <- function(dat, fileName="histW", output="screen", nBars=8, breaks=NULL,
   maxNoXLabels <- NA           # max number of border-values to display
   msg1 <- " NOT sufficent rights to write : "
   if(length(output) <1) output <- "screen" else if(length(output) >1) output <- output[1]
-  if(any(output %in% c("png","tiff","tif","jpg","jpeg"))) if(file.access(fileName,mode=0) ==0) {
+  if(any(output %in% c("png","tiff","tif","jpg","jpeg"))) if(file.access(fileName, mode=0) ==0) {
     if(file.access(fileName, mode=2) <0) stop("File exists ",msg1,fileName) }
   if(length(dat) <1) stop( " 'dat must be vector of numeric values")
   if(is.null(tit)) tit <- paste("Signal Histogram of",argN)
@@ -73,15 +73,15 @@ histW <- function(dat, fileName="histW", output="screen", nBars=8, breaks=NULL,
   if(length(breaks)==1) nBars <- breaks
   hist.ini <- graphics::hist(dat, plot=FALSE, breaks=nBars)       
   if(is.character(nBars)) nBars <- length(hist.ini$breaks)
-  if(sum(hist.ini$density,na.rm=TRUE) <1) hist.ini$density <- hist.ini$density/sum(hist.ini$density,na.rm=TRUE)
+  if(sum(hist.ini$density, na.rm=TRUE) <1) hist.ini$density <- hist.ini$density/sum(hist.ini$density, na.rm=TRUE)
   relCo <- rbind(rel=hist.ini$density, interv=1:length(hist.ini$counts))
   inte <- hist.ini$density
   maxCla <- which(inte==max(inte))
-  if(length(inte < nBars) & (sum(inte[maxCla:min(length(inte),maxCla+1)]) > 0.8*sum(inte) |
+  if(length(inte < nBars) && (sum(inte[maxCla:min(length(inte),maxCla+1)]) > 0.8*sum(inte) |
     sum(inte[maxCla:max(1,maxCla-1)]) > 0.8*sum(inte))) {
-    if(!silent) message(fxNa," too much information in 2 neighbour classes (out of ",length(inte),"), trying to increasing number of classes")
-    hist.ini <- graphics::hist(dat, plot=FALSE, breaks=nBars+1)              
-    relCo <- rbind(rel=hist.ini$density,interv=1:length(hist.ini$counts)) }
+    if(!silent) message(fxNa,"Too much information in 2 neighbour classes (out of ",length(inte),"), trying to increasing number of classes")
+    hist.ini <- graphics::hist(dat, plot=FALSE, breaks=nBars +1)              
+    relCo <- rbind(rel=hist.ini$density, interv=1:length(hist.ini$counts)) }
   mainHist <- hist.ini
   if(cropHist) {  
      ## crop borders to avoid showing very low bars not yet finished/implemented
@@ -103,31 +103,31 @@ histW <- function(dat, fileName="histW", output="screen", nBars=8, breaks=NULL,
     ## how many axis labels can one reasonably display ?
     if(debug) message("Initial ch1 ",signif(ch1,3),"   nCharLab ",nCharLab,"   nBars ",nBars)
     ch1 <- max(2+ ch1 *5 / (1 +nCharLab*xcex), 3)
-    if(length(maxNoXLabels)==1 & is.finite(maxNoXLabels)) if(nBars >maxNoXLabels) ch1 <- max(nBars %/% maxNoXLabels, ch1)
+    if(length(maxNoXLabels)==1 && is.finite(maxNoXLabels)) if(nBars >maxNoXLabels) ch1 <- max(nBars %/% maxNoXLabels, ch1)
     ch2 <- round(nBars/ch1)
     ch1 <- round(ch1) 
-    if(debug) message(" final ch1 ",signif(ch1,3),"   nBars ",nBars,"   ch2 ",ch2)
-    showBorder <- if(nBars >3 & nBars >ch1) ch2*(1:(nBars/ch2)) else 1:nBars 
+    if(debug) message("Final ch1 ",signif(ch1,3),"   nBars ",nBars,"   ch2 ",ch2)
+    showBorder <- if(nBars >3 && nBars >ch1) ch2*(1:(nBars/ch2)) else 1:nBars 
     ## define las                                           # x-axis numbers text orientation
-    txtLas <- if(length(las) !=1) 1+ (nCharLab >4) else las
+    txtLas <- if(length(las) !=1) 1 + (nCharLab >4) else las
       
     if(parDefault) graphics::par(mar=c(0.8 +txtLas, 5, 2.6, 0.8), cex.axis=xcex)                    # mar(bot,le,top,ri)
-    cexSubTi <- if(!is.numeric(cexSubTi) | length(cexSubTi) !=1) graphics::par("font.sub")*0.7
+    cexSubTi <- if(!is.numeric(cexSubTi) || length(cexSubTi) !=1) graphics::par("font.sub")*0.7
     txt2 <- c("Initial values range from  ","  to  ")
     graphics::plot(mainHist, xlab=xLab, ylab=yLab, col=useCol, border=useBord, main=tit, xaxt="n", las=1)
-    graphics::segments(hist.ini$breaks[showBorder], 0,hist.ini$breaks[showBorder],  -1*signif(max(hist.ini$counts,na.rm=TRUE)/110,3) ) # x-axis ticks
+    graphics::segments(hist.ini$breaks[showBorder], 0, hist.ini$breaks[showBorder], -1*signif(max(hist.ini$counts,na.rm=TRUE)/110,3) ) # x-axis ticks
     ## look for alternatve of making plot, rather as contour-lines for overlay ?
     if(isLog) {
       tx <- signif(c(2^min(dat), 2^hist.ini$breaks[-1*c(1,length(hist.ini$breaks))], 2^max(dat)),2)[showBorder]
       if(length(tx) > length(unique(tx))) tx <- signif(c(2^min(dat), 2^hist.ini$breaks[-1*c(1,length(hist.ini$breaks))], 2^max(dat)),3)[showBorder]
-      graphics::mtext(tx, at=hist.ini$breaks[showBorder], col=1, side=1, li=-0.2,cex=0.75, xlab=xLab, las=txtLas)
+      graphics::mtext(tx, at=hist.ini$breaks[showBorder], col=1, side=1, li=-0.2, cex=0.75, xlab=xLab, las=txtLas)
       txt2 <- paste(txt2[1], signif(2^min(dat,na.rm=TRUE),4), txt2[2], signif(2^max(dat,na.rm=TRUE),5))      # 'initial values range form ..to..'
     } else {
       tx <- signif(hist.ini$breaks[-1*length(hist.ini$breaks)],2)[showBorder]
       if(length(tx) > length(unique(tx))) tx <- signif(c(min(dat), hist.ini$breaks[-1*c(1,length(hist.ini$breaks))], max(dat)),3)[showBorder]
-      graphics::mtext(tx, at=hist.ini$breaks[showBorder], col=1, side=1, li=-0.2, cex=0.75,xlab=xLab,las=1)
+      graphics::mtext(tx, at=hist.ini$breaks[showBorder], col=1, side=1, li=-0.2, cex=0.75, xlab=xLab, las=1)
       txt2 <- paste(txt2[1], signif(min(dat,na.rm=TRUE),4), txt2[2], signif(max(dat,na.rm=TRUE),5)) }
-    if(!identical(subTi,FALSE)) graphics::mtext(if(is.null(subTi)) txt2 else subTi,li=-0.4,cex=cexSubTi)
+    if(!identical(subTi,FALSE)) graphics::mtext(if(is.null(subTi)) txt2 else subTi,li=-0.4, cex=cexSubTi)
   }
   if(output %in% c("png","tif","tiff","jpg","jpeg")) grDevices::dev.off() 
   tmp <- try(graphics::par(mar=opar$mar, cex.main=opar$font.sub), silent=TRUE)
