@@ -1,15 +1,14 @@
 #' Display numeric content of matrix as image  
 #'
-#' To get a quick overview of the distribution of data and, in particular, of local phenomena it is useful to express numeric values as colored boxes.
-#' Such an output can also be referred to as heatmap (note that the term 'hatmap' is also frequently associated with graphical display of hierarchcal clustering results).
+#' To get a quick overview of the spatial distribution of smaller data-sets it may be useful to display numeric values as colored boxes.
+#' Such an output may also be referred to as heatmap (note that the term 'heatmap' is frequently associated with graphical display of hierarchcal clustering results).
 #' The function \code{\link[graphics]{image}} provides the basic support to do so (ie heatmap without rearranging rows and columns by clustering).  
 #' To do this more conveniently, the function \code{imageW} offers additional options for displaying row- and column-names or displaying NA-values as custom-color.
 #'
 #' @details 
-#' If the main input \code{data} is numeric vector (an not matrix or data.frame) the values will be displayed as multiple columns and single row.
-#' This function allows two modes of operation : 1) plotting using standard R -graphics or 2) using the framework of grid- and lattice-graphics. (since version 1.2.6). 
-#' The latter version has comes integrate with a legend for the color-scale, allows adding grid-lines rotation of axis-labels and removing tick-marks.
-#' Please note that sometimes the center-color segment may not end up directly with the center-color, in thi case you may adjust using the argument \code{centColShift=-1}
+#' This function allows two modes of operation : 1) plotting using standard R -graphics or 2) using the framework of grid- and lattice-graphics (since version 1.2.6). 
+#' The latter version allows integrating a legend for the color-scale and adding grid-lines, rotation of axis-labels or removing tick-marks.
+#' Please note that sometimes the center-color segment may not end up directly with the center-color, in this case you may adjust using the argument \code{centColShift=-1}
 #'
 #' @param data (matrix or data.frame) main input
 #' @param latticeVersion (logical) use lattice for plotting (this will include a color-legend)
@@ -20,8 +19,8 @@
 #' @param rowNa (character) optional custom rownames
 #' @param colNa (character) optional custom colnames
 #' @param tit (character) custom figure title
-#' @param xLab (character) optional custom names for x-axis
-#' @param yLab (character) optional custom names for y-axis
+#' @param xLab (character) optional custom text for x-axis 'values'
+#' @param yLab (character) optional custom text for y-axis 'values'
 #' @param las (numeric) style of axis labels (see also \code{\link[graphics]{par}}); in case of \code{latticeVersion=TRUE} this argument will override default \code{rotXlab=0} and/or  \code{rotYlab=0}
 #' @param nColor (integer, only used in lattice version) number of color-blocks in color gradient (made based on central- and end-points from \code{col} 
 #' @param balanceCol (logical, only used in lattice version) if \code{TRUE} the color-radient aims to color the value closest to 0 with the center color (from \code{col} (default gray)
@@ -30,10 +29,10 @@
 #' @param centColShift (integer, only used in lattice version) shift central (default grey) color element for negative scale up or down (ie increase or reduce number of color-blocks for negatve values), 
 #'   used for correcting automatic scaling rounding issues to ensure the central elements captures 0  
 #' @param cexDispl (numeric, length=1, only used in lattice version) define cex size for displaying (rounded) values in plot, set to \code{NULL} for omitting
-#' @param panel.background.col (character, only used in lattice version) 
+#' @param panel.background.col (character, only used in lattice version)
+#' @param supLat (list, only used in lattice version) additional arguments/parameters passed to \code{levelplot}  
 #' @param rotXlab (numeric, 0 - 360, lattice version only) control rotation of x-axis labels
 #' @param rotYlab (numeric, 0 - 360, lattice version only) control rotation of y-axis labels
-#' @param ... (only used in lattice version) additional arguments/parameters passed to \code{levelplot} 
 #' @param cexXlab (numeric) cex-like expansion factor for x-axis labels  (see also \code{\link[graphics]{par}})
 #' @param cexAxs (numeric) cex-like expansion factor for x- and y-axis text/labels (see also \code{\link[graphics]{par}})
 #' @param cexYlab (numeric) cex-like expansion factor for y-axis labels  (see also \code{\link[graphics]{par}})
@@ -51,26 +50,50 @@
 #' imageW(as.matrix(iris[1:20,1:4]), latticeVersion=TRUE, col=c("blue","red"), 
 #'   rotXlab=45, yLab="Observation no", tit="Iris (head)")
 #' @export
-imageW <- function(data, latticeVersion=FALSE, transp=TRUE, NAcol="grey95", rowNa=NULL, colNa=NULL, tit=NULL, xLab=NA, yLab=NA, las=2, 
-  col=NULL, nColor=9, balanceCol=TRUE, gridCol="grey75", gridLty=1, centColShift=0, cexDispl=NULL, panel.background.col="white", 
-  rotXlab=0, rotYlab=0, ..., cexXlab=0.7, cexAxs=NULL, cexYlab=0.9, Xtck=0, Ytck=0, cexTit=1.6, silent=FALSE, debug=FALSE, callFrom=NULL) { 
+imageW <- function(data, latticeVersion=FALSE, transp=TRUE, NAcol="grey95", tit=NULL, rowNa=NULL, colNa=NULL, xLab=NULL, yLab=NULL, las=2, 
+  col=NULL, nColor=9, balanceCol=TRUE, gridCol="grey75", gridLty=1, centColShift=0, cexDispl=NULL, panel.background.col="white", supLat=list(),
+  rotXlab=0, rotYlab=0, cexXlab=0.7, cexAxs=NULL, cexYlab=0.9, Xtck=0, Ytck=0, cexTit=1.6, silent=FALSE, debug=FALSE, callFrom=NULL) { 
   ## improved version if image() or  levelplot()
   fxNa <- wrMisc::.composeCallName(callFrom, newNa="imageW")
   argNa <- deparse(substitute(data))
   if(isTRUE(debug)) silent <- FALSE else debug <- FALSE
   if(!isTRUE(silent)) silent <- FALSE
   doPlot <- if(length(data) >0) is.numeric(data) else FALSE
+  transp <- !isFALSE(transp)
   if(length(dim(data)) <2) data <- try(matrix(as.numeric(data), ncol=1, dimnames=list(names(data), NULL)), silent=TRUE)
   if(inherits(data, "try-error")) doPlot <- FALSE else {
     if(is.data.frame(data) && doPlot) {doPlot <- is.numeric(as.matrix(data)); data <- as.matrix(data)}}
+  if(debug) {message(fxNa," xiW0   debug: ",debug)}
   if(doPlot) {    
     ## checks & adjust
-    if(length(rowNa) <nrow(data)) rowNa <- rownames(data) 
+    if(length(xLab) >1 && !all(is.na(xLab))) {
+      if(transp) { 
+        if(length(xLab) ==ncol(data) && length(colNa) <1 ) { colNa <- xLab; xLab <- NA
+          if(!silent) message(fxNa,"(72) It seems you meant 'colNa' when using argument 'xLab' (interpreting as such) ...") 
+        } else { if(length(xLab) >1) if(!silent) message(fxNa,"Invalid entry for 'xLab'"); xLab <- NA }
+      } else {   
+        if(length(xLab) ==nrow(data) && length(rowNa) <1 ) { rowNa <- xLab; xLab <- NA
+          if(!silent) message(fxNa,"(76) It seems you meant 'rowNa' when using argument 'xLab' (interpreting as such) ...") 
+        } else { if(length(xLab) >1) if(!silent) message(fxNa,"Invalid entry for 'xLab'"); xLab <- NA }
+      } 
+    } else { if(length(xLab) >1) if(!silent) message(fxNa,"Invalid entry for 'xLab'"); xLab <- NA }
+    
+    if(length(yLab) >1 && !all(is.na(yLab))) {
+      if(transp) { 
+        if(length(yLab) ==nrow(data) && length(rowNa) <1 ) { rowNa <- yLab; yLab <- NA
+          if(!silent) message(fxNa,"(84) It seems you meant 'rowNa' when using argument 'yLab' (interpreting as such) ...")
+        } else { if(length(yLab) >1) if(!silent) message(fxNa,"Invalid entry for 'yLab'"); yLab <- NA }
+      } else {  
+        if(length(yLab) ==ncol(data) && length(colNa) <1 ) { colNa <- yLab; yLab <- NA
+          if(!silent) message(fxNa,"(88) It seems you meant 'colNa' when using argument 'yLab' (interpreting as such) ...")
+        } else { if(length(yLab) >1) if(!silent) message(fxNa,"Invalid entry for 'xLab'"); yLab <- NA}           
+      }      
+    } else { if(length(yLab) >1) if(!silent) message(fxNa,"Invalid entry for 'xLab'"); yLab <- NA}
+        if(length(rowNa) <nrow(data)) rowNa <- rownames(data) 
     if(length(rowNa) <1) rowNa <- if(length(nrow(data)) >1) 1:nrow(data) else ""
     if(length(colNa) < ncol(data)) colNa <- colnames(data)
     if(length(colNa) <1) colNa <- if(length(ncol(data)) >1) 1:ncol(data) else ""
-    if(is.null(xLab)) xLab <- ""
-    if(is.null(yLab)) yLab <- ""  
+    if(debug) {message(fxNa," xiW1"); xiW1 <- list(data=data,xLab=xLab,yLab=yLab,transp=transp, tit=tit,rowNa=rowNa,colNa=colNa)}
     if(latticeVersion) {
       ## reformat input
       if(!transp) data <- t(data)                 #  was initially written for transp=T, re-transform if not chosen
@@ -140,15 +163,16 @@ imageW <- function(data, latticeVersion=FALSE, transp=TRUE, NAcol="grey95", rowN
           lattice::panel.abline(v=0.5 +1:(ncol(data) -1), col=gridCol, lty=gridLty) }   # hor            
       }  
       ## lattice levelplot
-      if(doPlot) lattice::levelplot(z ~ x *y, data = ma2,  aspect=nrow(data)/ncol(data), col.regions=cols,
-        region = TRUE, cuts =length(cols) -1, xlab = xLab, ylab = yLab, main = tit,
+      if(doPlot) lattice::levelplot(z ~ x *y, data = ma2, aspect=nrow(data)/ncol(data), col.regions=cols,
+        region = TRUE, cuts =length(cols) -1, xlab = yLab, ylab = xLab, main = tit,
         scales=list(relation="free", x=list(at=1:ncol(data), labels=if(transp) colNa else rowNa, cex=cexXlab, rot=rotXlab, tck=as.numeric(Xtck)), 
           y=list(at=nrow(data):1, labels=if(transp) rowNa else colNa, cex=cexYlab, rot=rotYlab, tck=as.numeric(Ytck))),  # axis labels 
         par.settings=list(axis.line=list(col='black')), 
         panel=myPanel                                                                                                                      
       )   
     } else {
-      ## (until v1.2.5) standard graphics version
+      ## (until v1.2.5) standard graphics version  (ie non-lattice)
+      if(debug) message(fxNa," (175)  xLab=",xLab,"   yLab=",yLab)
       if(transp) data <- t(data)
       if(ncol(data) >1) data <- data[,ncol(data):1]                         # reverse for intuitive display left -> right
       if(identical(col,"heat.colors") || identical(col,"heatColors")) col <- rev(grDevices::heat.colors(sort(c(15, prod(dim(data)) +2))[2] ))
@@ -168,11 +192,13 @@ imageW <- function(data, latticeVersion=FALSE, transp=TRUE, NAcol="grey95", rowN
         col <- c(NAcol,col) }
       ## main plot
       yAt <- (0:(length(rowNa)-1))/(length(rowNa)-1)
+      if(debug) {message(fxNa," xiW2"); xiW2 <- list(data=data, xLab=xLab,yLab=yLab,transp=transp,tit=tit,rowNa=rowNa,colNa=colNa,yAt=yAt)}
       if(doPlot) {
-        graphics::image(data, col=col, xaxt="n", yaxt="n", main=tit, xlab=if(transp) xLab else yLab, ylab=if(transp) yLab else xLab, cex.main=cexTit)
-        graphics::mtext(at=(0:(length(colNa)-1))/(length(colNa)-1), colNa, side=if(transp) 1 else 2, line=0.3, las=las, cex=cexYlab)   # on bottom 
-        graphics::mtext(at=if(transp) rev(yAt) else yAt, rowNa, side=if(transp) 2 else 1, line=0.3, las=las, cex=cexXlab)   # on bottom  , cex=cexAxs
+        if(debug) message(fxNa," (197)  xLab=",xLab,"   yLab=",yLab)
+        graphics::image(data, col=col, xaxt="n", yaxt="n", main=tit, cex.main=cexTit, xlab=if(transp) yLab else xLab, ylab=if(transp) xLab else yLab)
+        graphics::mtext(at=(0:(length(colNa)-1))/(length(colNa)-1), colNa, side=if(transp) 1 else 2, line=0.3, las=las, cex=cexYlab)   # 'colNames'
+        graphics::mtext(at=if(transp) rev(yAt) else yAt, rowNa, side=if(transp) 2 else 1, line=0.3, las=las, cex=cexXlab)           # 'rowNames'
         graphics::box(col=grDevices::grey(0.8)) }}
     } else if(!silent) message(fxNa,"Argument 'data' invalid, please furnish matrix or data.frame with min 2 lines & min 1 col") 
 }  
-  
+    
